%Modified @2017-8-7
% we have 13 endogenous variables
close all;
dbstop if error
%dbstop in 'get_bank_zero_profit_diff_cond_on_Rk.m' at 11
var 
K           //capital stock
I           // investment
C           //consumption
R         // nominal rate
omegabar // cutoff value of risk
Rk          // return rate of capital
N           //net worth of enterpreneur
sigmat   // variable standard devation of risk shock
Interest_spread  // interest rate Interest_spread
credit   //  loan from bank by enterpreneur
Default_rate  //rate of bankruptancy
GDP     // output
A   //TFP
lam   //external finance premium
lamtilde // external finance premium shock
wedge //the financial wedge
Leverage // leverage
;

varexo sigma_e epslam epsa;

parameters  mu gamma alpha delta beta gam lambda_para we;
parameters rhosigma rhoa rholam sigmaa sigmalam sigma_ss;
mu=0.2149;          %monitoring cost parameter
gamma=0.97;    %survival rate
alpha=1/3;         %capital share
delta=0.02;        %depreciation rate
beta=1.03^(-.25); %discount rate
rhosigma=0.97; %persistence
gam=1;             %log utility
lambda_para = 1/beta-1; %for illustration, as the risk free rate, 3% annually
we = 0.01;

rhosigma = 0.97;
rhoa = 0.85;
rholam = 0.85;
sigmaa = 0.01;
sigmalam = 0.01;
sigmas = 0.07; %unanticipated risk shock, CRM(2014)
sigma_ss=0.2592; %steady state of standard dev. of risk shock

model;
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Auxiliary expressions.  These simplify the equations without adding
% additional variables. Noticing the timing scprits of the variables.
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
  # z        = (log(omegabar) + sigmat(-1)^2 / 2) / sigmat(-1);
  # zplus   = (log(omegabar(+1)) + sigmat^2 / 2) / sigmat;
  # F          = normcdf(z);
  # G          = normcdf(z - sigmat(-1));
  # d          =  mu * G  * (1 + Rk) * K(-1);
  # Fp1        = normcdf(zplus);
  # Gp1        = normcdf(zplus - sigmat);
  # GAMMA      = omegabar*(1-F)+G;
  # GAMMAp1    = omegabar(+1)*(1-Fp1)+Gp1;
  # dFp1       = normpdf(zplus) / omegabar(+1) / sigmat;
  
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Equilibrium equations.
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%(1) resource constraint
    A*K(-1)^alpha = C + I + d ;
  
% (2)Law of motion for capital, capital producer technolgy
    K = (1 - delta) * K(-1) + I;
  
% (3) Household FOC w.r.t. risk-free bonds
    1 = beta * (C(+1)/C)^(-gam)*(1+R);
  
% (4) entrepreneur's efficiency condition associated with the contract
    (1-Fp1)/(1-GAMMAp1)-((1 + Rk(+1)) / ((1 + R)*lam))*(1-Fp1-mu*omegabar(+1)*dFp1)
    /(1-((1 + Rk(+1)) / ((1 + R)*lam))*(GAMMAp1-mu*Gp1));
  
% (5) Definition of return of entrepreneurs, Rk
    1 + Rk = alpha*K(-1)^(alpha-1)  + 1 - delta;
    
%(6) Zero bank profit condition, i.e. the definition of leverage ratio
    K(-1)*(1 - ((1+Rk)/((1+R(-1))*lam))*(GAMMA-mu*G)) - N(-1);
  
%(7) Law of motion of net worth, omitting the entrepreneurial wage
    N= gamma*(1-GAMMA)*(1+Rk)*K(-1) +we;

%(8) borrowing:
    credit = K-N;

%(9) interest rate spread
    Interest_spread = ((1+Rk)/(1+R(-1)))*(K(-1)/credit(-1))*omegabar;

%(10) Shock 
   log(sigmat / sigma_ss) = rhosigma * log(sigmat(-1) / sigma_ss)  + sigma_e ;

%(11) the output of the economy
   GDP = C + I;

%(12) the external financial premium
    lam = exp(lambda_para+lamtilde);

%(13) lamtilde
    lamtilde  = rholam*lamtilde(-1) + epslam;

%(14) default rate
   Default_rate = F;

%(15) the financial wedge
   wedge = (1-(1+R)/(1+Rk(+1)));

%(16) TFP
    log(A) = rhoa*log(A(-1)) + epsa;

%(17) Leverage
    Leverage = K/N;
end;

shocks;
var sigma_e = sigmas^2; 
var epsa   = sigmaa^2;
var epslam = sigmalam^2;
end;

%this directive will invoke steady state file to have s.s.
steady;

stoch_simul(periods=1000,order=1,irf=20) K, I, C, R, omegabar, 
                   Rk, N, sigmat, Interest_spread, credit, Default_rate, GDP, wedge Leverage;
