function [residual, g1, g2, g3] = fin_acc_rbc_dynamic(y, x, params, steady_state, it_)
%
% Status : Computes dynamic model for Dynare
%
% Inputs :
%   y         [#dynamic variables by 1] double    vector of endogenous variables in the order stored
%                                                 in M_.lead_lag_incidence; see the Manual
%   x         [M_.exo_nbr by nperiods] double     matrix of exogenous variables (in declaration order)
%                                                 for all simulation periods
%   params    [M_.param_nbr by 1] double          vector of parameter values in declaration order
%   it_       scalar double                       time period for exogenous variables for which to evaluate the model
%
% Outputs:
%   residual  [M_.endo_nbr by 1] double    vector of residuals of the dynamic model equations in order of 
%                                          declaration of the equations
%   g1        [M_.endo_nbr by #dynamic variables] double    Jacobian matrix of the dynamic model equations;
%                                                           rows: equations in order of declaration
%                                                           columns: variables in order stored in M_.lead_lag_incidence
%   g2        [M_.endo_nbr by (#dynamic variables)^2] double   Hessian matrix of the dynamic model equations;
%                                                              rows: equations in order of declaration
%                                                              columns: variables in order stored in M_.lead_lag_incidence
%   g3        [M_.endo_nbr by (#dynamic variables)^3] double   Third order derivative matrix of the dynamic model equations;
%                                                              rows: equations in order of declaration
%                                                              columns: variables in order stored in M_.lead_lag_incidence
%
%
% Warning : this file is generated automatically by Dynare
%           from model file (.mod)

%
% Model equations
%

residual = zeros(17, 1);
z__ = (log(y(12))+y(4)^2/2)/y(4);
zplus__ = (log(y(26))+y(15)^2/2)/y(15);
F__ = normcdf(z__,0,1);
G__ = normcdf(z__-y(4),0,1);
d__ = params(1)*G__*(1+y(13))*y(1);
Fp1__ = normcdf(zplus__,0,1);
Gp1__ = normcdf(zplus__-y(15),0,1);
GAMMA__ = G__+y(12)*(1-F__);
GAMMAp1__ = y(26)*(1-Fp1__)+Gp1__;
dFp1__ = normpdf(zplus__,0,1)/y(26)/y(15);
T47 = normpdf(zplus__,0,1);
T72 = params(5)*(y(25)/y(10))^(-params(6));
T84 = (1+y(27))/((1+y(11))*y(21));
T93 = 1-T84*(GAMMAp1__-params(1)*Gp1__);
T106 = (1+y(13))/(y(21)*(1+y(2)));
T131 = (1+y(13))/(1+y(2))*y(1)/y(5);
T191 = getPowerDeriv(y(25)/y(10),(-params(6)),1);
T231 = 1/y(12)/y(4);
T238 = exp((-((z__-y(4))*(z__-y(4))))/2)/2.506628274631;
T239 = T231*T238;
T248 = exp((-(z__*z__))/2)/2.506628274631;
T265 = 1/y(26)/y(15);
T270 = exp((-(zplus__*zplus__))/2)/2.506628274631;
T272 = (-(T265*T270));
T279 = exp((-((zplus__-y(15))*(zplus__-y(15))))/2)/2.506628274631;
T280 = T265*T279;
T281 = 1-Fp1__+y(26)*T272+T280;
T344 = (y(4)*2*y(4)/2-(log(y(12))+y(4)^2/2))/(y(4)*y(4));
T346 = T238*(T344-1);
T373 = (y(15)*2*y(15)/2-(log(y(26))+y(15)^2/2))/(y(15)*y(15));
T375 = (-(T270*T373));
lhs =y(20)*y(1)^params(3);
rhs =y(10)+y(9)+d__;
residual(1)= lhs-rhs;
lhs =y(8);
rhs =y(9)+y(1)*(1-params(4));
residual(2)= lhs-rhs;
lhs =1;
rhs =T72*(1+y(11));
residual(3)= lhs-rhs;
residual(4) = (1-Fp1__)/(1-GAMMAp1__)-T84*(1-Fp1__-y(26)*params(1)*dFp1__)/T93;
lhs =1+y(13);
rhs =1+params(3)*y(1)^(params(3)-1)-params(4);
residual(5)= lhs-rhs;
residual(6) = y(1)*(1-T106*(GAMMA__-params(1)*G__))-y(3);
lhs =y(14);
rhs =y(1)*(1+y(13))*params(2)*(1-GAMMA__)+params(8);
residual(7)= lhs-rhs;
lhs =y(17);
rhs =y(8)-y(14);
residual(8)= lhs-rhs;
lhs =y(16);
rhs =y(12)*T131;
residual(9)= lhs-rhs;
lhs =log(y(15)/params(14));
rhs =params(9)*log(y(4)/params(14))+x(it_, 1);
residual(10)= lhs-rhs;
lhs =y(19);
rhs =y(10)+y(9);
residual(11)= lhs-rhs;
lhs =y(21);
rhs =exp(params(7)+y(22));
residual(12)= lhs-rhs;
lhs =y(22);
rhs =params(11)*y(7)+x(it_, 2);
residual(13)= lhs-rhs;
lhs =y(18);
rhs =F__;
residual(14)= lhs-rhs;
lhs =y(23);
rhs =1-(1+y(11))/(1+y(27));
residual(15)= lhs-rhs;
lhs =log(y(20));
rhs =params(10)*log(y(6))+x(it_, 3);
residual(16)= lhs-rhs;
lhs =y(24);
rhs =y(8)/y(14);
residual(17)= lhs-rhs;
if nargout >= 2,
  g1 = zeros(17, 30);

  %
  % Jacobian matrix
  %

  g1(1,1)=y(20)*getPowerDeriv(y(1),params(3),1)-params(1)*G__*(1+y(13));
  g1(1,9)=(-1);
  g1(1,10)=(-1);
  g1(1,12)=(-(y(1)*(1+y(13))*params(1)*T239));
  g1(1,13)=(-(params(1)*G__*y(1)));
  g1(1,4)=(-(y(1)*(1+y(13))*params(1)*T346));
  g1(1,20)=y(1)^params(3);
  g1(2,1)=(-(1-params(4)));
  g1(2,8)=1;
  g1(2,9)=(-1);
  g1(3,10)=(-((1+y(11))*params(5)*(-y(25))/(y(10)*y(10))*T191));
  g1(3,25)=(-((1+y(11))*params(5)*T191*1/y(10)));
  g1(3,11)=(-T72);
  g1(4,11)=(-((T93*(1-Fp1__-y(26)*params(1)*dFp1__)*(-((1+y(27))*y(21)))/((1+y(11))*y(21)*(1+y(11))*y(21))-T84*(1-Fp1__-y(26)*params(1)*dFp1__)*(-((GAMMAp1__-params(1)*Gp1__)*(-((1+y(27))*y(21)))/((1+y(11))*y(21)*(1+y(11))*y(21)))))/(T93*T93)));
  g1(4,26)=((1-GAMMAp1__)*T272-(1-Fp1__)*(-T281))/((1-GAMMAp1__)*(1-GAMMAp1__))-(T93*T84*(T272-(params(1)*dFp1__+y(26)*params(1)*(y(26)*T47*zplus__*(-T265)-T47)/(y(26)*y(26))/y(15)))-T84*(1-Fp1__-y(26)*params(1)*dFp1__)*(-(T84*(T281-params(1)*T280))))/(T93*T93);
  g1(4,27)=(-((T93*(1-Fp1__-y(26)*params(1)*dFp1__)*1/((1+y(11))*y(21))-T84*(1-Fp1__-y(26)*params(1)*dFp1__)*(-((GAMMAp1__-params(1)*Gp1__)*1/((1+y(11))*y(21)))))/(T93*T93)));
  g1(4,15)=((1-GAMMAp1__)*T375-(1-Fp1__)*(-(y(26)*T375+T279*(T373-1))))/((1-GAMMAp1__)*(1-GAMMAp1__))-(T93*T84*(T375-y(26)*params(1)*(y(15)*T47*zplus__*(-T373)/y(26)-T47/y(26))/(y(15)*y(15)))-T84*(1-Fp1__-y(26)*params(1)*dFp1__)*(-(T84*(y(26)*T375+T279*(T373-1)-params(1)*T279*(T373-1)))))/(T93*T93);
  g1(4,21)=(-((T93*(1-Fp1__-y(26)*params(1)*dFp1__)*(-((1+y(11))*(1+y(27))))/((1+y(11))*y(21)*(1+y(11))*y(21))-T84*(1-Fp1__-y(26)*params(1)*dFp1__)*(-((GAMMAp1__-params(1)*Gp1__)*(-((1+y(11))*(1+y(27))))/((1+y(11))*y(21)*(1+y(11))*y(21)))))/(T93*T93)));
  g1(5,1)=(-(params(3)*getPowerDeriv(y(1),params(3)-1,1)));
  g1(5,13)=1;
  g1(6,1)=1-T106*(GAMMA__-params(1)*G__);
  g1(6,2)=y(1)*(-((GAMMA__-params(1)*G__)*(-((1+y(13))*y(21)))/(y(21)*(1+y(2))*y(21)*(1+y(2)))));
  g1(6,12)=y(1)*(-(T106*(T239+1-F__+y(12)*(-(T231*T248))-params(1)*T239)));
  g1(6,13)=y(1)*(-((GAMMA__-params(1)*G__)*1/(y(21)*(1+y(2)))));
  g1(6,3)=(-1);
  g1(6,4)=y(1)*(-(T106*(T346+y(12)*(-(T248*T344))-params(1)*T346)));
  g1(6,21)=y(1)*(-((GAMMA__-params(1)*G__)*(-((1+y(13))*(1+y(2))))/(y(21)*(1+y(2))*y(21)*(1+y(2)))));
  g1(7,1)=(-((1+y(13))*params(2)*(1-GAMMA__)));
  g1(7,12)=(-(y(1)*(1+y(13))*params(2)*(-(T239+1-F__+y(12)*(-(T231*T248))))));
  g1(7,13)=(-(y(1)*params(2)*(1-GAMMA__)));
  g1(7,14)=1;
  g1(7,4)=(-(y(1)*(1+y(13))*params(2)*(-(T346+y(12)*(-(T248*T344))))));
  g1(8,8)=(-1);
  g1(8,14)=1;
  g1(8,17)=1;
  g1(9,1)=(-(y(12)*(1+y(13))/(1+y(2))*1/y(5)));
  g1(9,2)=(-(y(12)*y(1)/y(5)*(-(1+y(13)))/((1+y(2))*(1+y(2)))));
  g1(9,12)=(-T131);
  g1(9,13)=(-(y(12)*y(1)/y(5)*1/(1+y(2))));
  g1(9,16)=1;
  g1(9,5)=(-(y(12)*(1+y(13))/(1+y(2))*(-y(1))/(y(5)*y(5))));
  g1(10,4)=(-(params(9)*1/params(14)/(y(4)/params(14))));
  g1(10,15)=1/params(14)/(y(15)/params(14));
  g1(10,28)=(-1);
  g1(11,9)=(-1);
  g1(11,10)=(-1);
  g1(11,19)=1;
  g1(12,21)=1;
  g1(12,22)=(-exp(params(7)+y(22)));
  g1(13,7)=(-params(11));
  g1(13,22)=1;
  g1(13,29)=(-1);
  g1(14,12)=(-(T231*T248));
  g1(14,4)=(-(T248*T344));
  g1(14,18)=1;
  g1(15,11)=1/(1+y(27));
  g1(15,27)=(-(1+y(11)))/((1+y(27))*(1+y(27)));
  g1(15,23)=1;
  g1(16,6)=(-(params(10)*1/y(6)));
  g1(16,20)=1/y(20);
  g1(16,30)=(-1);
  g1(17,8)=(-(1/y(14)));
  g1(17,14)=(-((-y(8))/(y(14)*y(14))));
  g1(17,24)=1;
end
if nargout >= 3,
  %
  % Hessian matrix
  %

  g2 = sparse([],[],[],17,900);
end
if nargout >= 4,
  %
  % Third order derivatives
  %

  g3 = sparse([],[],[],17,27000);
end
end
