function [residual, g1, g2] = fin_acc_rbc_static(y, x, params)
%
% Status : Computes static model for Dynare
%
% Inputs : 
%   y         [M_.endo_nbr by 1] double    vector of endogenous variables in declaration order
%   x         [M_.exo_nbr by 1] double     vector of exogenous variables in declaration order
%   params    [M_.param_nbr by 1] double   vector of parameter values in declaration order
%
% Outputs:
%   residual  [M_.endo_nbr by 1] double    vector of residuals of the static model equations 
%                                          in order of declaration of the equations
%   g1        [M_.endo_nbr by M_.endo_nbr] double    Jacobian matrix of the static model equations;
%                                                     columns: variables in declaration order
%                                                     rows: equations in order of declaration
%   g2        [M_.endo_nbr by (M_.endo_nbr)^2] double   Hessian matrix of the static model equations;
%                                                       columns: variables in declaration order
%                                                       rows: equations in order of declaration
%
%
% Warning : this file is generated automatically by Dynare
%           from model file (.mod)

residual = zeros( 17, 1);

%
% Model equations
%

z__ = (log(y(5))+y(8)^2/2)/y(8);
zplus__ = (log(y(5))+y(8)^2/2)/y(8);
F__ = normcdf(z__,0,1);
G__ = normcdf(z__-y(8),0,1);
d__ = params(1)*G__*(1+y(6))*y(1);
Fp1__ = normcdf(zplus__,0,1);
Gp1__ = normcdf(zplus__-y(8),0,1);
GAMMA__ = G__+y(5)*(1-F__);
GAMMAp1__ = y(5)*(1-Fp1__)+Gp1__;
dFp1__ = normpdf(zplus__,0,1)/y(5)/y(8);
T40 = normpdf(zplus__,0,1);
T70 = (1+y(6))/((1+y(4))*y(14));
T111 = (1+y(6))/(1+y(4))*y(1)/y(10);
T167 = (-((1+y(6))*y(14)))/((1+y(4))*y(14)*(1+y(4))*y(14));
T174 = (1-T70*(GAMMAp1__-params(1)*Gp1__))*(1-T70*(GAMMAp1__-params(1)*Gp1__));
T189 = 1/y(5)/y(8);
T196 = exp((-((z__-y(8))*(z__-y(8))))/2)/2.506628274631;
T206 = exp((-(zplus__*zplus__))/2)/2.506628274631;
T208 = (-(T189*T206));
T215 = exp((-((zplus__-y(8))*(zplus__-y(8))))/2)/2.506628274631;
T216 = T189*T215;
T217 = 1-Fp1__+y(5)*T208+T216;
T250 = exp((-(z__*z__))/2)/2.506628274631;
T299 = (y(8)*2*y(8)/2-(log(y(5))+y(8)^2/2))/(y(8)*y(8));
T349 = 1/params(14)/(y(8)/params(14));
T362 = (-((1+y(6))*(1+y(4))))/((1+y(4))*y(14)*(1+y(4))*y(14));
lhs =y(13)*y(1)^params(3);
rhs =y(3)+y(2)+d__;
residual(1)= lhs-rhs;
lhs =y(1);
rhs =y(2)+y(1)*(1-params(4));
residual(2)= lhs-rhs;
lhs =1;
rhs =params(5)*(1+y(4));
residual(3)= lhs-rhs;
residual(4) = (1-Fp1__)/(1-GAMMAp1__)-T70*(1-Fp1__-y(5)*params(1)*dFp1__)/(1-T70*(GAMMAp1__-params(1)*Gp1__));
lhs =1+y(6);
rhs =1+params(3)*y(1)^(params(3)-1)-params(4);
residual(5)= lhs-rhs;
residual(6) = y(1)*(1-T70*(GAMMA__-params(1)*G__))-y(7);
lhs =y(7);
rhs =y(1)*(1+y(6))*params(2)*(1-GAMMA__)+params(8);
residual(7)= lhs-rhs;
lhs =y(10);
rhs =y(1)-y(7);
residual(8)= lhs-rhs;
lhs =y(9);
rhs =y(5)*T111;
residual(9)= lhs-rhs;
lhs =log(y(8)/params(14));
rhs =log(y(8)/params(14))*params(9)+x(1);
residual(10)= lhs-rhs;
lhs =y(12);
rhs =y(3)+y(2);
residual(11)= lhs-rhs;
lhs =y(14);
rhs =exp(params(7)+y(15));
residual(12)= lhs-rhs;
lhs =y(15);
rhs =y(15)*params(11)+x(2);
residual(13)= lhs-rhs;
lhs =y(11);
rhs =F__;
residual(14)= lhs-rhs;
lhs =y(16);
rhs =1-(1+y(4))/(1+y(6));
residual(15)= lhs-rhs;
lhs =log(y(13));
rhs =log(y(13))*params(10)+x(3);
residual(16)= lhs-rhs;
lhs =y(17);
rhs =y(1)/y(7);
residual(17)= lhs-rhs;
if ~isreal(residual)
  residual = real(residual)+imag(residual).^2;
end
if nargout >= 2,
  g1 = zeros(17, 17);

  %
  % Jacobian matrix
  %

  g1(1,1)=y(13)*getPowerDeriv(y(1),params(3),1)-params(1)*G__*(1+y(6));
  g1(1,2)=(-1);
  g1(1,3)=(-1);
  g1(1,5)=(-(y(1)*(1+y(6))*params(1)*T189*T196));
  g1(1,6)=(-(params(1)*G__*y(1)));
  g1(1,8)=(-(y(1)*(1+y(6))*params(1)*T196*(T299-1)));
  g1(1,13)=y(1)^params(3);
  g1(2,1)=1-(1-params(4));
  g1(2,2)=(-1);
  g1(3,4)=(-params(5));
  g1(4,4)=(-(((1-T70*(GAMMAp1__-params(1)*Gp1__))*(1-Fp1__-y(5)*params(1)*dFp1__)*T167-T70*(1-Fp1__-y(5)*params(1)*dFp1__)*(-((GAMMAp1__-params(1)*Gp1__)*T167)))/T174));
  g1(4,5)=((1-GAMMAp1__)*T208-(1-Fp1__)*(-T217))/((1-GAMMAp1__)*(1-GAMMAp1__))-((1-T70*(GAMMAp1__-params(1)*Gp1__))*T70*(T208-(params(1)*dFp1__+y(5)*params(1)*(y(5)*T40*zplus__*(-T189)-T40)/(y(5)*y(5))/y(8)))-T70*(1-Fp1__-y(5)*params(1)*dFp1__)*(-(T70*(T217-params(1)*T216))))/T174;
  g1(4,6)=(-(((1-T70*(GAMMAp1__-params(1)*Gp1__))*(1-Fp1__-y(5)*params(1)*dFp1__)*1/((1+y(4))*y(14))-T70*(1-Fp1__-y(5)*params(1)*dFp1__)*(-((GAMMAp1__-params(1)*Gp1__)*1/((1+y(4))*y(14)))))/T174));
  g1(4,8)=((1-GAMMAp1__)*(-(T206*T299))-(1-Fp1__)*(-(y(5)*(-(T206*T299))+T215*(T299-1))))/((1-GAMMAp1__)*(1-GAMMAp1__))-((1-T70*(GAMMAp1__-params(1)*Gp1__))*T70*((-(T206*T299))-y(5)*params(1)*(y(8)*T40*zplus__*(-T299)/y(5)-T40/y(5))/(y(8)*y(8)))-T70*(1-Fp1__-y(5)*params(1)*dFp1__)*(-(T70*(y(5)*(-(T206*T299))+T215*(T299-1)-params(1)*T215*(T299-1)))))/T174;
  g1(4,14)=(-(((1-T70*(GAMMAp1__-params(1)*Gp1__))*(1-Fp1__-y(5)*params(1)*dFp1__)*T362-T70*(1-Fp1__-y(5)*params(1)*dFp1__)*(-((GAMMAp1__-params(1)*Gp1__)*T362)))/T174));
  g1(5,1)=(-(params(3)*getPowerDeriv(y(1),params(3)-1,1)));
  g1(5,6)=1;
  g1(6,1)=1-T70*(GAMMA__-params(1)*G__);
  g1(6,4)=y(1)*(-((GAMMA__-params(1)*G__)*T167));
  g1(6,5)=y(1)*(-(T70*(T189*T196+1-F__+y(5)*(-(T189*T250))-params(1)*T189*T196)));
  g1(6,6)=y(1)*(-((GAMMA__-params(1)*G__)*1/((1+y(4))*y(14))));
  g1(6,7)=(-1);
  g1(6,8)=y(1)*(-(T70*(T196*(T299-1)+y(5)*(-(T250*T299))-params(1)*T196*(T299-1))));
  g1(6,14)=y(1)*(-((GAMMA__-params(1)*G__)*T362));
  g1(7,1)=(-((1+y(6))*params(2)*(1-GAMMA__)));
  g1(7,5)=(-(y(1)*(1+y(6))*params(2)*(-(T189*T196+1-F__+y(5)*(-(T189*T250))))));
  g1(7,6)=(-(y(1)*params(2)*(1-GAMMA__)));
  g1(7,7)=1;
  g1(7,8)=(-(y(1)*(1+y(6))*params(2)*(-(T196*(T299-1)+y(5)*(-(T250*T299))))));
  g1(8,1)=(-1);
  g1(8,7)=1;
  g1(8,10)=1;
  g1(9,1)=(-(y(5)*(1+y(6))/(1+y(4))*1/y(10)));
  g1(9,4)=(-(y(5)*y(1)/y(10)*(-(1+y(6)))/((1+y(4))*(1+y(4)))));
  g1(9,5)=(-T111);
  g1(9,6)=(-(y(5)*y(1)/y(10)*1/(1+y(4))));
  g1(9,9)=1;
  g1(9,10)=(-(y(5)*(1+y(6))/(1+y(4))*(-y(1))/(y(10)*y(10))));
  g1(10,8)=T349-params(9)*T349;
  g1(11,2)=(-1);
  g1(11,3)=(-1);
  g1(11,12)=1;
  g1(12,14)=1;
  g1(12,15)=(-exp(params(7)+y(15)));
  g1(13,15)=1-params(11);
  g1(14,5)=(-(T189*T250));
  g1(14,8)=(-(T250*T299));
  g1(14,11)=1;
  g1(15,4)=1/(1+y(6));
  g1(15,6)=(-(1+y(4)))/((1+y(6))*(1+y(6)));
  g1(15,16)=1;
  g1(16,13)=1/y(13)-params(10)*1/y(13);
  g1(17,1)=(-(1/y(7)));
  g1(17,7)=(-((-y(1))/(y(7)*y(7))));
  g1(17,17)=1;
  if ~isreal(g1)
    g1 = real(g1)+2*imag(g1);
  end
end
if nargout >= 3,
  %
  % Hessian matrix
  %

  g2 = sparse([],[],[],17,289);
end
end
